@@ -1,4 +1,6 @@
 from importlib import import_module
+from pathlib import Path
+from shutil import rmtree
 
 from aiohttp import TCPConnector
 from aiohttp_client_cache.backends.filesystem import FileBackend
@@ -21,12 +23,20 @@ async def run():
 
     cache = FileBackend("mmc-export", use_temp=True, allowed_methods=("GET", "POST", "HEAD"))
     async with CachedSession(cache=cache, connector=TCPConnector(limit=0)) as session: 
+        if args.skip_cache: session.cache.disabled = True # type: ignore
 
         match args.cmd:
             case "gh-login": await add_github_token(session); return # type: ignore
             case "gh-logout": 
                 url = "https://github.com/settings/connections/applications/8011f22f502b091464de"
                 print(f"You can revoke your access token by the following link: \n{url}"); return
+            case "purge-cache":
+                if args.cache_web or args.cache_all: 
+                    await session.cache.clear() # type: ignore
+                if args.cache_files or args.cache_all: 
+                    cache_directory = Path().home() / ".cache/mmc-export"
+                    rmtree(cache_directory, ignore_errors=True)
+                return
 
         parser = Parser(args.input, session) # type: ignore
         intermediate = await parser.parse()
